<?php
namespace EEPROM;

use Index\Environment;
use Index\Data\DbTools;
use Syokuhou\SharpConfig;

define('PRM_STARTUP', microtime(true));
define('PRM_ROOT', __DIR__);
define('PRM_CLI', PHP_SAPI === 'cli');
define('PRM_DEBUG', is_file(PRM_ROOT . '/.debug'));
define('PRM_PUBLIC', PRM_ROOT . '/public');
define('PRM_SOURCE', PRM_ROOT . '/src');
define('PRM_MIGRATIONS', PRM_ROOT . '/database');
define('PRM_UPLOADS', PRM_PUBLIC . '/data');
define('PRM_THUMBS', PRM_PUBLIC . '/thumb');

require_once PRM_ROOT . '/vendor/autoload.php';

Environment::setDebug(PRM_DEBUG);
mb_internal_encoding('utf-8');
date_default_timezone_set('utc');

$cfg = SharpConfig::fromFile(PRM_ROOT . '/config.cfg');

if($cfg->hasValues('sentry:dsn'))
    (function($cfg) {
        \Sentry\init([
            'dsn' => $cfg->getString('dsn'),
            'traces_sample_rate' => $cfg->getFloat('tracesRate', 0.2),
            'profiles_sample_rate' => $cfg->getFloat('profilesRate', 0.2),
        ]);

        set_exception_handler(function(\Throwable $ex) {
            \Sentry\captureException($ex);
        });
    })($cfg->scopeTo('sentry'));

if(!is_dir(PRM_UPLOADS))
    mkdir(PRM_UPLOADS, 0775, true);
if(!is_dir(PRM_THUMBS))
    mkdir(PRM_THUMBS, 0775, true);

$db = DbTools::create($cfg->getString('database:dsn', 'null:'));
$db->execute('SET SESSION time_zone = \'+00:00\', sql_mode = \'STRICT_TRANS_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO,NO_ENGINE_SUBSTITUTION\';');

$eeprom = new EEPROMContext($cfg, $db);
